#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-smallcheck
version:              0.2
visibility:           public
id:                   test-framework-smallcheck-0.2-Dg0XGlPlDLECsLY4HRmoTx
key:                  test-framework-smallcheck-0.2-Dg0XGlPlDLECsLY4HRmoTx
license:              BSD-3-Clause
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/smallcheck
synopsis:             Support for SmallCheck tests in test-framework
description:          Support for SmallCheck tests in test-framework
category:             Testing
abi:                  74be8ecf34937cd2270bed64958e1156
exposed:              True
exposed-modules:      Test.Framework.Providers.SmallCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-smallcheck-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-smallcheck
hs-libraries:         HStest-framework-smallcheck-0.2-Dg0XGlPlDLECsLY4HRmoTx
depends:
    base-4.18.2.1 smallcheck-1.2.1.1-GU8sXl4GLXV6vRMxteau1L
    test-framework-0.8.2.3-HtqlCb8d1eBHA7kBalFrJK transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-smallcheck/html/test-framework-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

